==> publit-io-0.0.2-sources.jar: com/publit/publit_io/constant/FilesExtensionParams.java <==
package com.publit.publit_io.constant;

/**
 * Files extension params.
 */
public class FilesExtensionParams {

    private FilesExtensionParams() {
        // not to be instantiated in public
    }

    /**
     * Used for listing file with JPG extention.
     */
    public static final String JPG = "jpg";

    /**
     * Used for listing file with JPEG extention.
     */
    public static final String JPEG = "jpeg";

    /**
     * Used for listing file with JPE extention.
     */
    public static final String JPE = "jpe";

    /**
     * Used for listing file with PNG extention.
     */
    public static final String PNG = "png";

    /**
     * Used for listing file with GIF extention.
     */
    public static final String GIF = "gif";

    /**
     * Used for listing file with BMP extention.
     */
    public static final String BMP = "bmp";

    /**
     * Used for listing file with PSD extention.
     */
    public static final String PSD = "psd";

    /**
     * Used for listing file with WEBP extention.
     */
    public static final String WEBP = "webp";

    /**
     * Used for listing file with AI extention.
     */
    public static final String AI = "ai";

    /**
     * Used for listing file with TIF extention.
     */
    public static final String TIF = "tif";

    /**
     * Used for listing file with TIFF extention.
     */
    public static final String TIFF = "tiff";

    /**
     * Used for listing file with MP4 extention.
     */
    public static final String MP4 = "mp4";

    /**
     * Used for listing file with WEBM extention.
     */
    public static final String WEBM = "webm";

    /**
     * Used for listing file with OGV extention.
     */
    public static final String OGV = "ogv";

    /**
     * Used for listing file with AVI extention.
     */
    public static final String AVI = "avi";

    /**
     * Used for listing file with MOV extention.
     */
    public static final String MOV = "mov";

    /**
     * Used for listing file with FLV extention.
     */
    public static final String FLV = "flv";

    /**
     * Used for listing file with THREE_GP extention.
     */
    public static final String THREE_GP = "3gp";

    /**
     * Used for listing file with THREE_G2 extention.
     */
    public static final String THREE_G2 = "3g2";

    /**
     * Used for listing file with WMV extention.
     */
    public static final String WMV = "wmv";

    /**
     * Used for listing file with MPEG extention.
     */
    public static final String MPEG = "mpeg";

    /**
     * Used for listing file with MKV extention.
     */
    public static final String MKV = "mkv";

}

==> publit-io-0.0.5-sources.jar: com/publit/publit_io/constant/FilesExtensionParams.java <==
package com.publit.publit_io.constant;

/**
 * Files extension params.
 */
public class FilesExtensionParams {

    private FilesExtensionParams() {
        // not to be instantiated in public
    }

    /**
     * Used for listing file with JPG extention.
     */
    public static final String JPG = "jpg";

    /**
     * Used for listing file with JPEG extention.
     */
    public static final String JPEG = "jpeg";

    /**
     * Used for listing file with JPE extention.
     */
    public static final String JPE = "jpe";

    /**
     * Used for listing file with PNG extention.
     */
    public static final String PNG = "png";

    /**
     * Used for listing file with GIF extention.
     */
    public static final String GIF = "gif";

    /**
     * Used for listing file with BMP extention.
     */
    public static final String BMP = "bmp";

    /**
     * Used for listing file with PSD extention.
     */
    public static final String PSD = "psd";

    /**
     * Used for listing file with WEBP extention.
     */
    public static final String WEBP = "webp";

    /**
     * Used for listing file with AI extention.
     */
    public static final String AI = "ai";

    /**
     * Used for listing file with TIF extention.
     */
    public static final String TIF = "tif";

    /**
     * Used for listing file with TIFF extention.
     */
    public static final String TIFF = "tiff";

    /**
     * Used for listing file with MP4 extention.
     */
    public static final String MP4 = "mp4";

    /**
     * Used for listing file with WEBM extention.
     */
    public static final String WEBM = "webm";

    /**
     * Used for listing file with OGV extention.
     */
    public static final String OGV = "ogv";

    /**
     * Used for listing file with AVI extention.
     */
    public static final String AVI = "avi";

    /**
     * Used for listing file with MOV extention.
     */
    public static final String MOV = "mov";

    /**
     * Used for listing file with FLV extention.
     */
    public static final String FLV = "flv";

    /**
     * Used for listing file with THREE_GP extention.
     */
    public static final String THREE_GP = "3gp";

    /**
     * Used for listing file with THREE_G2 extention.
     */
    public static final String THREE_G2 = "3g2";

    /**
     * Used for listing file with WMV extention.
     */
    public static final String WMV = "wmv";

    /**
     * Used for listing file with MPEG extention.
     */
    public static final String MPEG = "mpeg";

    /**
     * Used for listing file with MKV extention.
     */
    public static final String MKV = "mkv";

    /**
     * Used for listing file with MP3 extension.
     */
    public static final String MP3 = "mp3";

    /**
     * Used for listing file with WAV extension.
     */
    public static final String WAV = "wav";

    /**
     * Used for listing file with OGG extension.
     */
    public static final String OGG = "ogg";

    /**
     * Used for listing file with ACC extension.
     */
    public static final String ACC = "aac";

    /**
     * Used for listing file with AIFF extension.
     */
    public static final String AIFF = "aiff";

    /**
     * Used for listing file with AMR extension.
     */
    public static final String AMR = "amr";

    /**
     * Used for listing file with AC3 extension.
     */
    public static final String AC3 = "ac3";

    /**
     * Used for listing file with AU extension.
     */
    public static final String AU = "au";

    /**
     * Used for listing file with FLAC extension.
     */
    public static final String FLAC = "flac";

    /**
     * Used for listing file with M4A extension.
     */
    public static final String M4A = "m4a";

    /**
     * Used for listing file with AAC extension.
     */
    public static final String AAC = "aac";

    /**
     * Used for listing file with RA extension.
     */
    public static final String RA = "ra";

    /**
     * Used for listing file with VOC extension.
     */
    public static final String VOC = "voc";

    /**
     * Used for listing file with WMA extension.
     */
    public static final String WMA = "wma";

}
